@@ -16,7 +16,7 @@ import pathlib
 from .Utils import logged_func, print_color, Color, unify_joinpath, force_rmtree, run
 from .Content import Content, ContentList
 from .Config import Config
-
+from .Templates import Galileo
 
 class TemplateError(BaseException):
     pass
@@ -44,87 +44,86 @@ class Builder:
         2. clone from remote for git theme
         3. install deps for theme
         """
-        template = ''
-        template_dep_file = ''
-        mvrk_path = self._config.mvrk_path
+        # template = ''
+        # template_dep_file = ''
+        # mvrk_path = self._config.mvrk_path
 
-        def clone_remote_theme(config: dict):
-            repo_dir = os.path.abspath(mvrk_path + '/Templates/' + config['name'])
-            if os.path.exists(repo_dir):
-                force_rmtree(repo_dir)
-
-            repo_url = config['url']
-            repo_branch = config.get('branch', 'master')
-            repo_tag = config.get('tag', '')
-
-            def safe_run(command, cwd):
-                try:
-                    run(command, cwd)
-                except:
-                    raise TemplateError('Cannot fetch theme from '+repo_url)
-
-            safe_run('git clone -b %s %s %s' %
-                     (repo_branch, repo_url, repo_dir), mvrk_path)
-            if repo_tag != '':
-                safe_run('git checkout %s' & repo_tag, repo_dir)
-
-        # 根据不同配置情况获取主题文件
-        if type(self._config.template) == str:
-            # 如果主题配置项是一个字符串，则用户选用的是默认主题
-            built_in_themes = ['Kepler', 'Galileo']
-            if not os.path.exists(unify_joinpath(mvrk_path + '/Templates', self._config.template)):
-                # 如果没有相应的主题文件
-                if self._config.template in built_in_themes:
-                    # 如果主题是内置主题的一种，通过仓库获取主题
-                    clone_remote_theme({
-                        "name": self._config.template,
-                        "type": "git",
-                        "url": "https://github.com/AlanDecode/Maverick-Theme-%s.git" % self._config.template,
-                        "branch": "latest"
-                    })
-                    template = '.'.join(['Templates', self._config.template])
-                    template_dep_file = mvrk_path + '/Templates/%s/requirements.txt' % self._config.template
-                else:
-                    # 否则，提示没有此主题
-                    raise TemplateError(
-                        'Can not found local theme '+self._config.template)
-            else:
-                # TODO 如果是用户自己创建了一个同名文件
-                # 如果存在响应的主题文件
-                template = '.'.join(['Templates', self._config.template])
-                template_dep_file = mvrk_path + '/Templates/%s/requirements.txt' % self._config.template
-
-        elif type(self._config.template) == dict:
-            # 如果主题配置项是一个字典，则根据配置获取主题文件
-            if self._config.template['type'] == 'local':
-                local_dir = os.path.abspath(self._config.template['path'])
-                if not os.path.exists(local_dir):
-                    raise TemplateError(
-                        'Can not found local theme '+self._config.template['name'])
-                else:
-                    sys.path.insert(0, os.path.dirname(local_dir))
-                    template = self._config.template['name']
-                    template_dep_file = unify_joinpath(
-                        local_dir, 'requirements.txt')
-            elif self._config.template['type'] == 'git':
-                clone_remote_theme(self._config.template)
-                template = '.'.join(
-                    ['Templates', self._config.template['name']])
-                template_dep_file = mvrk_path + '/Templates/%s/requirements.txt' % self._config.template['name']
-
-        else:
-            raise TemplateError('Invalid template config',
-                                str(self._config.template))
-
-        # handle deps for theme
-        if os.path.exists(template_dep_file) and os.path.isfile(template_dep_file):
-            try:
-                run('pip install -r %s' % template_dep_file, '.')
-            except:
-                raise TemplateError('Can not install dependencies for theme.')
+        # def clone_remote_theme(config: dict):
+        #     repo_dir = os.path.abspath(mvrk_path + '/Templates/' + config['name'])
+        #     if os.path.exists(repo_dir):
+        #         force_rmtree(repo_dir)
+        #
+        #     repo_url = config['url']
+        #     repo_branch = config.get('branch', 'master')
+        #     repo_tag = config.get('tag', '')
+        #
+        #     def safe_run(command, cwd):
+        #         try:
+        #             run(command, cwd)
+        #         except:
+        #             raise TemplateError('Cannot fetch theme from '+repo_url)
+        #
+        #     safe_run('git clone -b %s %s %s' %
+        #              (repo_branch, repo_url, repo_dir), mvrk_path)
+        #     if repo_tag != '':
+        #         safe_run('git checkout %s' & repo_tag, repo_dir)
+        #
+        # # 根据不同配置情况获取主题文件
+        # if type(self._config.template) == str:
+        #     # 如果主题配置项是一个字符串，则用户选用的是默认主题
+        #     built_in_themes = ['Kepler', 'Galileo']
+        #     if not os.path.exists(unify_joinpath(mvrk_path + '/Templates', self._config.template)):
+        #         # 如果没有相应的主题文件
+        #         if self._config.template in built_in_themes:
+        #             # 如果主题是内置主题的一种，通过仓库获取主题
+        #             clone_remote_theme({
+        #                 "name": self._config.template,
+        #                 "type": "git",
+        #                 "url": "https://github.com/AlanDecode/Maverick-Theme-%s.git" % self._config.template,
+        #                 "branch": "latest"
+        #             })
+        #             template = '.'.join(['Templates', self._config.template])
+        #             template_dep_file = mvrk_path + '/Templates/%s/requirements.txt' % self._config.template
+        #         else:
+        #             # 否则，提示没有此主题
+        #             raise TemplateError(
+        #                 'Can not found local theme '+self._config.template)
+        #     else:
+        #         # TODO 如果是用户自己创建了一个同名文件
+        #         # 如果存在响应的主题文件
+        #         template = '.'.join(['Templates', self._config.template])
+        #         template_dep_file = mvrk_path + '/Templates/%s/requirements.txt' % self._config.template
+        #
+        # elif type(self._config.template) == dict:
+        #     # 如果主题配置项是一个字典，则根据配置获取主题文件
+        #     if self._config.template['type'] == 'local':
+        #         local_dir = os.path.abspath(self._config.template['path'])
+        #         if not os.path.exists(local_dir):
+        #             raise TemplateError(
+        #                 'Can not found local theme '+self._config.template['name'])
+        #         else:
+        #             sys.path.insert(0, os.path.dirname(local_dir))
+        #             template = self._config.template['name']
+        #             template_dep_file = unify_joinpath(
+        #                 local_dir, 'requirements.txt')
+        #     elif self._config.template['type'] == 'git':
+        #         clone_remote_theme(self._config.template)
+        #         template = '.'.join(
+        #             ['Templates', self._config.template['name']])
+        #         template_dep_file = mvrk_path + '/Templates/%s/requirements.txt' % self._config.template['name']
+        #
+        # else:
+        #     raise TemplateError('Invalid template config',
+        #                         str(self._config.template))
+        #
+        # # handle deps for theme
+        # if os.path.exists(template_dep_file) and os.path.isfile(template_dep_file):
+        #     try:
+        #         run('pip install -r %s' % template_dep_file, '.')
+        #     except:
+        #         raise TemplateError('Can not install dependencies for theme.')
 
         # 导入主题到运行环境
-        from .Templates import Galileo
         self._template = Galileo
 
     def build_all(self):
